fields

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	// ScopeNamespaced identifies a namespaced Kubernetes kind.
	ScopeNamespaced = "Namespaced"
	// ScopeCluster identifies a cluster-scoped Kubernetes kind.
	ScopeCluster = "Cluster"
)

Variables

This section is empty.

Functions

func Flatten

func Flatten(schemaJSON []byte, opts Options) (string, error)

Flatten decodes schemaJSON and returns its greppable field index.

func FlattenMap

func FlattenMap(root map[string]any, opts Options) (string, error)

FlattenMap returns the greppable field index for root without mutating it.

Types

type Options

type Options struct {
	GVK                schema.GroupVersionKind
	Scope              string
	Source             string
	Deprecated         bool
	DeprecationWarning string
}

Options controls field index generation for a single Kubernetes kind.

Jump to